@@ -136,7 +136,8 @@ setMethodS3("getSubsetToUpdate", "ScaleNormalization", function(this, ..., verbo
     } else {
       subsetToUpdate <- intersect(subsetToUpdate, possibleCells);
     }
-    rm(possibleCells);
+    # Not needed anymore
+    possibleCells <- NULL;
     verbose && cat(verbose, "'subsetToUpdate' (after): ");
     verbose && str(verbose, subsetToUpdate);
 
@@ -218,7 +219,8 @@ setMethodS3("getSubsetToAvg", "ScaleNormalization", function(this, ..., verbose=
       } # if (is.null(subset))
 
       subsetToAvg <- subset;
-      rm(subset);
+      # Not needed anymore
+      subset <- NULL;
 
       verbose && exit(verbose);
     }
@@ -244,7 +246,8 @@ setMethodS3("getSubsetToAvg", "ScaleNormalization", function(this, ..., verbose=
     } else {
       subsetToAvg <- intersect(subsetToAvg, possibleCells);
     }
-    rm(possibleCells);
+    # Not needed anymore
+    possibleCells <- NULL;
     verbose && cat(verbose, "'subsetToAvg' (after): ");
     verbose && str(verbose, subsetToAvg);
 
@@ -380,7 +383,7 @@ setMethodS3("process", "ScaleNormalization", function(this, ..., skip=FALSE, for
     pathname <- AffymetrixFile$renameToUpperCaseExt(pathname);
 
     # Already normalized?
-    if (isFile(pathname) && skip) {
+    if (skip && isFile(pathname)) {
       verbose && cat(verbose, "Normalized data file already exists: ",
                                                                    pathname);
       verbose && exit(verbose);
@@ -415,7 +418,8 @@ setMethodS3("process", "ScaleNormalization", function(this, ..., skip=FALSE, for
     verbose && exit(verbose);
 
     # Garbage collect
-    rm(x, xM);
+    # Not needed anymore
+    x <- xM <- NULL;
     gc <- gc();
     verbose && print(verbose, gc);
 
@@ -444,14 +448,25 @@ setMethodS3("process", "ScaleNormalization", function(this, ..., skip=FALSE, for
 
     # Create CEL file to store results, if missing
     verbose && enter(verbose, "Creating CEL file for results, if missing");
-    createFrom(df, filename=pathname, path=NULL, verbose=less(verbose));
+
+    # Write to a temporary file (allow rename of existing one if forced)
+    isFile <- (!skip && isFile(pathname));
+    pathnameT <- pushTemporaryFile(pathname, isFile=isFile, verbose=verbose);
+
+    createFrom(df, filename=pathnameT, path=NULL, verbose=less(verbose));
     verbose && exit(verbose);
 
     verbose && enter(verbose, "Storing normalized signals");
 #    updateDataFlat(ceN, data=data, verbose=less(verbose));
-#    rm(data);
-    updateCel(pathname, indices=subsetToUpdate, intensities=x);
-    rm(x);
+#    # Not needed anymore
+#    data <- NULL;
+    updateCel(pathnameT, indices=subsetToUpdate, intensities=x);
+    # Not needed anymore
+    x <- NULL;
+
+    # Rename temporary file
+    pathname <- popTemporaryFile(pathnameT, verbose=verbose);
+
     verbose && exit(verbose);
 
     verbose && exit(verbose);
