@@ -14,14 +14,15 @@
 # }
 #
 # \usage{
-#   \method{doRMA}{AffymetrixCelSet}(csR, arrays=NULL, uniquePlm=FALSE, drop=TRUE, verbose=FALSE, ...)
-#   \method{doRMA}{default}(dataSet, ..., verbose=FALSE)
+#   @usage doRMA,AffymetrixCelSet
+#   @usage doRMA,default
 # }
 #
 # \arguments{
 #  \item{csR, dataSet}{An @see "AffymetrixCelSet" (or the name of an @see "AffymetrixCelSet").}
 #  \item{arrays}{A @integer @vector specifying the subset of arrays
 #   to run RMA on.  If @NULL, all arrays are considered.}
+#  \item{flavor}{A character string specifying what model fitting algorithm to be used, cf. @see "RmaPlm".}
 #  \item{uniquePlm}{If @TRUE, the log-additive probe-summarization model
 #   is done on probeset with \emph{unique} sets of probes.
 #   If @FALSE, the summarization is done on "as-is" probesets as
@@ -45,7 +46,7 @@
 #
 # @author "HB"
 #*/###########################################################################
-setMethodS3("doRMA", "AffymetrixCelSet", function(csR, arrays=NULL, uniquePlm=FALSE, drop=TRUE, verbose=FALSE, ...) {
+setMethodS3("doRMA", "AffymetrixCelSet", function(csR, arrays=NULL, flavor=c("affyPLM", "oligo"), uniquePlm=FALSE, drop=TRUE, verbose=FALSE, ...) {
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -61,6 +62,9 @@ setMethodS3("doRMA", "AffymetrixCelSet", function(csR, arrays=NULL, uniquePlm=FA
     arrays <- Arguments$getIndices(arrays, max=length(csR));
   }
 
+  # Argument 'flavor':
+  flavor <- match.arg(flavor);
+
   # Argument 'uniquePlm':
   uniquePlm <- Arguments$getLogical(uniquePlm);
 
@@ -124,6 +128,7 @@ setMethodS3("doRMA", "AffymetrixCelSet", function(csR, arrays=NULL, uniquePlm=FA
     tags <- c("RBC");
     tags <- c(tags, "QN");
     tags <- c(tags, "RMA");
+    if (flavor != "affyPLM") tags <- c(tags, flavor);
 
     # Try to load the final TCN data set
     ces <- tryCatch({
@@ -165,7 +170,8 @@ setMethodS3("doRMA", "AffymetrixCelSet", function(csR, arrays=NULL, uniquePlm=FA
   }
 
   # Clean up
-  rm(csR, bc);
+  # Not needed anymore
+  csR <- bc <- NULL;
   gc <- gc();
   verbose && print(verbose, gc);
 
@@ -180,7 +186,8 @@ setMethodS3("doRMA", "AffymetrixCelSet", function(csR, arrays=NULL, uniquePlm=FA
     res <- c(res, list(qn=qn, csN=csN));
   }
   # Clean up
-  rm(csB, qn);
+  # Not needed anymore
+  csB <- qn <- NULL;
   gc <- gc();
   verbose && print(verbose, gc);
 
@@ -210,12 +217,13 @@ setMethodS3("doRMA", "AffymetrixCelSet", function(csR, arrays=NULL, uniquePlm=FA
     verbose && exit(verbose);
   }
 
-  plm <- RmaPlm(csN);
+  plm <- RmaPlm(csN, flavor=flavor);
   verbose && print(verbose, plm);
   if (length(findUnitsTodo(plm)) > 0) {
     units <- fit(plm, verbose=verbose);
     verbose && str(verbose, units);
-    rm(units);
+    # Not needed anymore
+    units <- NULL;
   }
   verbose && print(verbose, gc);
   ces <- getChipEffectSet(plm);
@@ -227,7 +235,8 @@ setMethodS3("doRMA", "AffymetrixCelSet", function(csR, arrays=NULL, uniquePlm=FA
   }
 
   # Clean up
-  rm(plm, csN);
+  # Not needed anymore
+  plm <- csN <- NULL;
   gc <- gc();
   verbose && print(verbose, gc);
 
@@ -243,6 +252,8 @@ setMethodS3("doRMA", "AffymetrixCelSet", function(csR, arrays=NULL, uniquePlm=FA
 
 
 setMethodS3("doRMA", "default", function(dataSet, ..., verbose=FALSE) {
+  require("aroma.affymetrix") || throw("Package not loaded: aroma.affymetrix");
+
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -264,7 +275,8 @@ setMethodS3("doRMA", "default", function(dataSet, ..., verbose=FALSE) {
   res <- doRMA(csR, ..., verbose=verbose);
 
   # Clean up
-  rm(csR);
+  # Not needed anymore
+  csR <- NULL;
   gc <- gc();
 
   verbose && exit(verbose);
@@ -275,6 +287,8 @@ setMethodS3("doRMA", "default", function(dataSet, ..., verbose=FALSE) {
 
 ############################################################################
 # HISTORY:
+# 2013-07-03
+# o Added argument 'flavor' or doRMA().
 # 2013-05-02
 # o Removed argument 'ram' in favor of aroma option 'memory/ram'.
 # 2013-04-29
