@@ -2,7 +2,7 @@
 # Replication test
 #
 # Description:
-# This test verifies that aroma.affymetrix can reproduce the gcRMA 
+# This test verifies that aroma.affymetrix can reproduce the gcRMA
 # chip-effect estimates as estimated by gcrma.
 #
 # Author: Mark Robinson and Henrik Bengtsson
@@ -26,12 +26,12 @@ print(csR);
 
 
 # ----------------------------------
-# RMA estimates by aroma.affymetrix 
+# RMA estimates by aroma.affymetrix
 # ----------------------------------
 verbose && enter(verbose, "gcRMA by aroma.affymetrix");
 
 res <- doGCRMA(csR, drop=FALSE, verbose=verbose);
-print(res); 
+print(res);
 
 # Extract chip effects on the log2 scale
 ces <- res$ces;
@@ -65,38 +65,41 @@ verbose && exit(verbose);
 o <- match(rownames(theta0), rownames(theta));
 theta <- theta[o,];
 
-# (a) Assert correlations
+# Calculate statistics
 rho <- diag(cor(theta, theta0));
 print(rho);
 print(range(rho));
-stopifnot(all(rho > 0.99995));
-
-# (b) Assert differences
 e <- (theta - theta0);
 print(summary(e));
-stopifnot(mean(as.vector(e^2)) < 0.001);
-stopifnot(sd(as.vector(e^2)) < 0.003);
-stopifnot(quantile(abs(e), 0.99) < 0.10);
-stopifnot(max(abs(e)) < 0.30);
 
-# (c) Visual comparison
+# (a) Visual comparison
 toPNG(getFullName(csR), tags=c("doGCRMA_vs_gcrma"), width=800, {
   par(mar=c(5,5,4,2)+0.1, cex.main=2, cex.lab=2, cex.axis=1.5);
-  
-  layout(matrix(1:9, ncol=3, byrow=TRUE));
-  
+
+  layout(matrix(1:16, ncol=4, byrow=TRUE));
+
   xlab <- expression(log[2](theta[gcrma]));
   ylab <- expression(log[2](theta[aroma.affymetrix]));
   for (kk in seq_len(ncol(theta))) {
     main <- colnames(theta)[kk];
     plot(theta0[,kk], theta[,kk], pch=".", xlab=xlab, ylab=ylab, main=main);
     abline(0,1, col="blue");
+    stext(side=3, pos=0, line=-1.1, cex=1.2, substitute(rho==x, list(x=rho[kk])));
   }
-  
+
   xlab <- expression(log[2](theta[aroma.affymetrix]/theta[gcrma]));
   plotDensity(e, xlab=xlab);
 });
 
+# (b) Assert correlations
+stopifnot(all(rho > 0.99995));
+
+# (c) Assert differences
+stopifnot(mean(as.vector(e^2)) < 0.001);
+stopifnot(sd(as.vector(e^2)) < 0.003);
+stopifnot(quantile(abs(e), 0.99) < 0.10);
+stopifnot(max(abs(e)) < 0.30);
+
 
 verbose && print(verbose, sessionInfo());
 
